@@ -1,12 +1,12 @@
 # coding=utf8
 
-# Copyright 2018-2025 JDCLOUD.COM
+# Copyright 2018 JDCLOUD.COM
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-#     http:#www.apache.org/licenses/LICENSE-2.0
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
@@ -30,11 +30,11 @@ class Logger(object):
     @abc.abstractmethod
     def log(self, level, message):
         if level <= self.__level:
-            print message
+            print(message)
 
 
-default_logger = Logger(INFO)
+DEFAULT_LOGGER = Logger(INFO)
 
 
 def get_default_logger():
-    return default_logger
+    return DEFAULT_LOGGER
